using FalcoEngine;
using System;

public class JointManager : MonoBehaviour
{
    public GameObject joint = null;
    public bool joined = false;

    private HingeJoint hingeJoint;
    private Wire wire;
    private Joint connection;


    void Start()
    {
        hingeJoint = GetComponent<HingeJoint>();
        wire = FindObjectOfType<Wire>();
        connection = FindObjectOfType<Joint>();
    }

    float GetDistance(Vector3 first, Vector3 second)
    {
        return (float)Math.Pow((Math.Pow(Math.Abs(first.x - second.x), 2f) + Math.Pow(Math.Abs(first.y - second.y), 2f)), 0.5f);
    }

    void Connect(GameObject obj)
    {
        joined = true;
        joint = obj;
        transform.rotation = Quaternion.Euler(0, 0, 0);
        hingeJoint.anchor = obj.transform.position - transform.position;
        hingeJoint.anchor = new Vector3(hingeJoint.anchor.x, hingeJoint.anchor.y, 0f);
        hingeJoint.connectedObject = joint.rigidbody;
    }

    void Disconnect()
    {
        hingeJoint.connectedObject = null;
        joined = false;
        joint = null;
    }

    void Update()
    {

        if (!joined)
        {
            wire.gameObject.enabled = false;
            if (Input.GetMouseButtonDown(0))
                Connect(connection.gameObject);
        }
        else
        {
            wire.gameObject.enabled = true;
            wire.transform.rotation = Quaternion.Euler(270f, 0f, 0f);

            wire.transform.scale = new Vector3(wire.transform.scale.x, wire.transform.scale.y, GetDistance(transform.position, joint.transform.position) * 50f);

            wire.transform.position = transform.position + (joint.transform.position - transform.position) / 2f;

            Vector3 direction = transform.position - wire.transform.position;
            direction -= new Vector3(0f, 0f, direction.z);
            wire.transform.rotation = Quaternion.LookRotation(direction, new Vector3(0f, 0f, 1f));

            if (!Input.GetMouseButton(0))
            {
                Disconnect();
            }
        }
    }
}
